import React, { useRef } from "react";
import styled from "styled-components";
import { useLastRound } from "../../../domain/gameStore";
import useMapWithMarkers from "./useMapWithMarkers";
import NextRoundButton from "./NextRoundButton";

const SummaryDiv = styled.div`
  position: absolute;
  display: flex;
  flex-flow: column nowrap;
  background-color: #333;
  z-index: 1;
  bottom: 16px;
  right: 8px;
  padding: 8px;
`

const ScoreSpan = styled.span`
  padding-bottom: 2px;
`;

const MapDiv = styled.div`
  position: absolute;
  height: 100%;
  width: 100%;
`

export default () => {
  // get the info about the last round
  const { roundNum, score, totalScore, targetPoint } = useLastRound();

  // draw the map
  const mapDivRef = useRef(null);
  useMapWithMarkers(mapDivRef, roundNum, targetPoint);
  
  return (
    <div>
      <MapDiv ref={mapDivRef} />
      <SummaryDiv>
        <ScoreSpan>Score for Round {roundNum}: {score}</ScoreSpan>
        <ScoreSpan>Running Total: {totalScore}</ScoreSpan>
        <NextRoundButton/>
      </SummaryDiv>
    </div>
  );
};
